==> fastfetch-2.12.0.tar.gz: fastfetch-2.12.0/src/modules/modules.h <==
#pragma once

// For "fastfetch.c" and "flashfetch.c"

#include "modules/battery/battery.h"
#include "modules/bios/bios.h"
#include "modules/bluetooth/bluetooth.h"
#include "modules/brightness/brightness.h"
#include "modules/board/board.h"
#include "modules/break/break.h"
#include "modules/camera/camera.h"
#include "modules/chassis/chassis.h"
#include "modules/cpu/cpu.h"
#include "modules/cpuusage/cpuusage.h"
#include "modules/command/command.h"
#include "modules/colors/colors.h"
#include "modules/cursor/cursor.h"
#include "modules/custom/custom.h"
#include "modules/datetime/datetime.h"
#include "modules/disk/disk.h"
#include "modules/diskio/diskio.h"
#include "modules/display/display.h"
#include "modules/de/de.h"
#include "modules/font/font.h"
#include "modules/gamepad/gamepad.h"
#include "modules/gpu/gpu.h"
#include "modules/host/host.h"
#include "modules/icons/icons.h"
#include "modules/kernel/kernel.h"
#include "modules/lm/lm.h"
#include "modules/loadavg/loadavg.h"
#include "modules/locale/locale.h"
#include "modules/localip/localip.h"
#include "modules/media/media.h"
#include "modules/memory/memory.h"
#include "modules/monitor/monitor.h"
#include "modules/netio/netio.h"
#include "modules/opengl/opengl.h"
#include "modules/opencl/opencl.h"
#include "modules/os/os.h"
#include "modules/packages/packages.h"
#include "modules/physicaldisk/physicaldisk.h"
#include "modules/physicalmemory/physicalmemory.h"
#include "modules/player/player.h"
#include "modules/poweradapter/poweradapter.h"
#include "modules/processes/processes.h"
#include "modules/publicip/publicip.h"
#include "modules/separator/separator.h"
#include "modules/shell/shell.h"
#include "modules/sound/sound.h"
#include "modules/swap/swap.h"
#include "modules/terminal/terminal.h"
#include "modules/terminalfont/terminalfont.h"
#include "modules/terminalsize/terminalsize.h"
#include "modules/terminaltheme/terminaltheme.h"
#include "modules/theme/theme.h"
#include "modules/title/title.h"
#include "modules/uptime/uptime.h"
#include "modules/users/users.h"
#include "modules/version/version.h"
#include "modules/vulkan/vulkan.h"
#include "modules/wallpaper/wallpaper.h"
#include "modules/weather/weather.h"
#include "modules/wifi/wifi.h"
#include "modules/wm/wm.h"
#include "modules/wmtheme/wmtheme.h"

==> fastfetch-2.15.0.tar.gz: fastfetch-2.15.0/src/modules/modules.h <==
#pragma once

// For "fastfetch.c" and "flashfetch.c"

#include "modules/battery/battery.h"
#include "modules/bios/bios.h"
#include "modules/bluetooth/bluetooth.h"
#include "modules/brightness/brightness.h"
#include "modules/board/board.h"
#include "modules/bootmgr/bootmgr.h"
#include "modules/break/break.h"
#include "modules/camera/camera.h"
#include "modules/chassis/chassis.h"
#include "modules/cpu/cpu.h"
#include "modules/cpucache/cpucache.h"
#include "modules/cpuusage/cpuusage.h"
#include "modules/command/command.h"
#include "modules/colors/colors.h"
#include "modules/cursor/cursor.h"
#include "modules/custom/custom.h"
#include "modules/datetime/datetime.h"
#include "modules/disk/disk.h"
#include "modules/diskio/diskio.h"
#include "modules/display/display.h"
#include "modules/de/de.h"
#include "modules/editor/editor.h"
#include "modules/font/font.h"
#include "modules/gamepad/gamepad.h"
#include "modules/gpu/gpu.h"
#include "modules/host/host.h"
#include "modules/icons/icons.h"
#include "modules/initsystem/initsystem.h"
#include "modules/kernel/kernel.h"
#include "modules/lm/lm.h"
#include "modules/loadavg/loadavg.h"
#include "modules/locale/locale.h"
#include "modules/localip/localip.h"
#include "modules/media/media.h"
#include "modules/memory/memory.h"
#include "modules/monitor/monitor.h"
#include "modules/netio/netio.h"
#include "modules/opengl/opengl.h"
#include "modules/opencl/opencl.h"
#include "modules/os/os.h"
#include "modules/packages/packages.h"
#include "modules/physicaldisk/physicaldisk.h"
#include "modules/physicalmemory/physicalmemory.h"
#include "modules/player/player.h"
#include "modules/poweradapter/poweradapter.h"
#include "modules/processes/processes.h"
#include "modules/publicip/publicip.h"
#include "modules/separator/separator.h"
#include "modules/shell/shell.h"
#include "modules/sound/sound.h"
#include "modules/swap/swap.h"
#include "modules/terminal/terminal.h"
#include "modules/terminalfont/terminalfont.h"
#include "modules/terminalsize/terminalsize.h"
#include "modules/terminaltheme/terminaltheme.h"
#include "modules/theme/theme.h"
#include "modules/title/title.h"
#include "modules/uptime/uptime.h"
#include "modules/users/users.h"
#include "modules/version/version.h"
#include "modules/vulkan/vulkan.h"
#include "modules/wallpaper/wallpaper.h"
#include "modules/weather/weather.h"
#include "modules/wifi/wifi.h"
#include "modules/wm/wm.h"
#include "modules/wmtheme/wmtheme.h"
